@@ -5,8 +5,9 @@ use strict;
 use warnings;
 use Log::Any '$log';
 
-our $VERSION = '0.13'; # VERSION
+our $VERSION = '0.14'; # VERSION
 
+use Data::Clean::FromJSON;
 use Data::Clean::JSON;
 use JSON;
 
@@ -22,8 +23,9 @@ has _pa => (
         Perinci::Access::Schemeless->new();
     });
 
-my $json = JSON->new->allow_nonref;
-my $cleanser = Data::Clean::JSON->new;
+my $json       = JSON->new->allow_nonref;
+my $cleanser   = Data::Clean::JSON->get_cleanser;
+my $cleanserfj = Data::Clean::FromJSON->get_cleanser;
 
 $|++;
 
@@ -70,7 +72,10 @@ sub run {
         }
         $log->tracef("Read JSON from stdin: %s", $req_json);
         my $req;
-        eval { $req = $json->decode($req_json) };
+        eval {
+            $req = $json->decode($req_json);
+            $cleanserfj->clean_in_place($req);
+        };
         my $e = $@;
         if ($e) {
             #$self->res([400, "Invalid JSON ($e)"]);
@@ -105,7 +110,7 @@ Perinci::Access::Simple::Server::Pipe - (Base) class for creating Riap::Simple s
 
 =head1 VERSION
 
-version 0.13
+version 0.14
 
 =head1 SYNOPSIS
 
